@@ -11,10 +11,10 @@ class TestLoader(unittest.TestCase):
         self.assertEqual(
             testcase_obj.config.name, "request methods testcase with variables"
         )
-        self.assertEqual(len(testcase_obj.teststeps), 3)
+        self.assertEqual(len(testcase_obj.teststeps), 4)
 
     def test_load_json_file_file_format_error(self):
-        json_tmp_file = "/tmp/tmp.json"
+        json_tmp_file = "tmp.json"
         # create empty file
         with open(json_tmp_file, "w") as f:
             f.write("")
@@ -41,7 +41,7 @@ class TestLoader(unittest.TestCase):
         os.remove(json_tmp_file)
 
     def test_load_testcases_bad_filepath(self):
-        testcase_file_path = os.path.join(os.getcwd(), "tests/data/demo")
+        testcase_file_path = os.path.join(os.getcwd(), "examples/data/demo")
         with self.assertRaises(exceptions.FileNotFound):
             loader.load_testcase_file(testcase_file_path)
 
@@ -97,7 +97,11 @@ class TestLoader(unittest.TestCase):
         )
 
     def test_load_env_path_not_exist(self):
-        dot_env_path = os.path.join(os.getcwd(), "tests", "data",)
+        dot_env_path = os.path.join(
+            os.getcwd(),
+            "tests",
+            "data",
+        )
         env_variables_mapping = loader.load_dot_env_file(dot_env_path)
         self.assertEqual(env_variables_mapping, {})
 
@@ -111,7 +115,7 @@ class TestLoader(unittest.TestCase):
         start_path = os.path.join(os.getcwd(), "examples", "httpbin")
         self.assertEqual(
             loader.locate_file(start_path, "debugtalk.py"),
-            os.path.join(os.getcwd(), "examples/httpbin/debugtalk.py"),
+            os.path.join(os.getcwd(), "examples", "httpbin", "debugtalk.py"),
         )
         self.assertEqual(
             loader.locate_file("examples/httpbin/", "debugtalk.py"),
@@ -119,5 +123,5 @@ class TestLoader(unittest.TestCase):
         )
         self.assertEqual(
             loader.locate_file("examples/httpbin/", "debugtalk.py"),
-            os.path.join(os.getcwd(), "examples/httpbin/debugtalk.py"),
+            os.path.join(os.getcwd(), "examples", "httpbin", "debugtalk.py"),
         )
