@@ -38,6 +38,8 @@ class SessionRunner(object):
     session: HttpSession = None
     case_id: Text = ""
     root_dir: Text = ""
+    thrift_client = None
+    db_engine = None
 
     __config: TConfig
     __project_meta: ProjectMeta = None
@@ -87,6 +89,14 @@ class SessionRunner(object):
         self.__export = export
         return self
 
+    def with_thrift_client(self, thrift_client) -> "SessionRunner":
+        self.thrift_client = thrift_client
+        return self
+
+    def with_db_engine(self, db_engine) -> "SessionRunner":
+        self.db_engine = db_engine
+        return self
+
     def __parse_config(self, param: Dict = None) -> None:
         # parse config variables
         self.__config.variables.update(self.__session_variables)
@@ -216,6 +226,8 @@ class SessionRunner(object):
                 self.__run_step(step)
         finally:
             logger.info(f"generate testcase log: {self.__log_path}")
+            if USE_ALLURE:
+                allure.attach.file(self.__log_path, name='all log', attachment_type=allure.attachment_type.TEXT)
 
         self.__duration = time.time() - self.__start_at
         return self
