@@ -10,7 +10,7 @@ from httprunner.exceptions import ValidationFailure
 from httprunner.models import IStep, StepResult, TStep
 from httprunner.models import SqlMethodEnum, TSqlRequest
 from httprunner.response import SqlResponseObject
-from httprunner.runner import HttpRunner
+from httprunner.runner import HttpRunner, USE_ALLURE
 from httprunner.step_request import (
     StepRequestExtraction,
     StepRequestValidation,
@@ -50,10 +50,10 @@ def run_step_sql_request(runner: HttpRunner, step: TStep) -> StepResult:
         name=step.name,
         success=False,
     )
-    step.variables = runner.merge_step_variables(step.variables)
+    step_variables = runner.merge_step_variables(step.variables)
     # parse
     request_dict = step.sql_request.dict()
-    parsed_request_dict = runner.parser.parse_data(request_dict, step.variables)
+    parsed_request_dict = runner.parser.parse_data(request_dict, step_variables)
     config = runner.get_config()
     parsed_request_dict["db_config"]["psm"] = (
         parsed_request_dict["db_config"]["psm"] or config.db.psm
@@ -92,8 +92,20 @@ def run_step_sql_request(runner: HttpRunner, step: TStep) -> StepResult:
 
     # setup hooks
     if step.setup_hooks:
-        call_hooks(runner, step.setup_hooks, step.variables, "setup request")
+        call_hooks(runner, step.setup_hooks, step_variables, "setup request")
 
+    # log request
+    sql_request_print = "====== sql request details ======\n"
+    sql_request_print += f"sql: {step.sql_request.sql}\n"
+    for k, v in parsed_request_dict.items():
+        v = utils.omit_long_data(v)
+        sql_request_print += f"{k}: {repr(v)}\n"
+
+    sql_request_print += "\n"
+
+    if USE_ALLURE:
+        import allure
+        allure.attach(sql_request_print, name="sql request details", attachment_type=allure.attachment_type.TEXT)
     logger.info(f"Executing SQL: {parsed_request_dict['sql']}")
     if step.sql_request.method == SqlMethodEnum.FETCHONE:
         sql_resp = runner.db_engine.fetchone(parsed_request_dict["sql"])
@@ -113,30 +125,26 @@ def run_step_sql_request(runner: HttpRunner, step: TStep) -> StepResult:
         raise SqlMethodNotSupport(
             f"step.sql_request.method {parsed_request_dict['method']} not support"
         )
+    # log response
+    sql_response_print = "====== sql response details ======\n"
+    for k, v in sql_resp.items():
+        v = utils.omit_long_data(v)
+        sql_response_print += f"{k}: {repr(v)}\n"
+
+    if USE_ALLURE:
+        import allure
+        allure.attach(sql_request_print, name="sql response details", attachment_type=allure.attachment_type.TEXT)
+
     resp_obj = SqlResponseObject(sql_resp, parser=runner.parser)
-    step.variables["sql_response"] = resp_obj
+    step_variables["sql_response"] = resp_obj
 
     # teardown hooks
     if step.teardown_hooks:
-        call_hooks(runner, step.teardown_hooks, step.variables, "teardown request")
+        call_hooks(runner, step.teardown_hooks, step_variables, "teardown request")
 
     def log_sql_req_resp_details():
         err_msg = "\n{} SQL DETAILED REQUEST & RESPONSE {}\n".format("*" * 32, "*" * 32)
-
-        # log request
-        err_msg += "====== sql request details ======\n"
-        err_msg += f"sql: {step.sql_request.sql}\n"
-        for k, v in parsed_request_dict.items():
-            v = utils.omit_long_data(v)
-            err_msg += f"{k}: {repr(v)}\n"
-
-        err_msg += "\n"
-
-        # log response
-        err_msg += "====== sql response details ======\n"
-        for k, v in sql_resp.items():
-            v = utils.omit_long_data(v)
-            err_msg += f"{k}: {repr(v)}\n"
+        err_msg += sql_request_print + sql_response_print
         logger.error(err_msg)
 
     # extract
@@ -144,7 +152,7 @@ def run_step_sql_request(runner: HttpRunner, step: TStep) -> StepResult:
     extract_mapping = resp_obj.extract(extractors)
     step_result.export_vars = extract_mapping
 
-    variables_mapping = step.variables
+    variables_mapping = step_variables
     variables_mapping.update(extract_mapping)
 
     # validate
@@ -159,6 +167,7 @@ def run_step_sql_request(runner: HttpRunner, step: TStep) -> StepResult:
         session_data = runner.session.data
         session_data.success = step_result.success
         session_data.validators = resp_obj.validation_results
+
         # save step data
         step_result.data = session_data
         step_result.elapsed = time.time() - start_time
